@@ -347,8 +347,8 @@ plot.gge <- function(x,
                      col.circle = "gray",
                      col.alpha.circle = 0.5,
                      leg.lab = NULL,
-                     size.text.gen = 4,
-                     size.text.env = 4,
+                     size.text.gen = 3.5,
+                     size.text.env = 3.5,
                      size.text.lab = 12,
                      size.text.win = 4.5,
                      size.line = 0.5,
